local nebu_img = require "bkg.lib.nebula_image"
nebu_img.init( "ngc-2440-2" )
